package com.ruoyi.frequency.platformanswer.service;

import java.util.List;
import com.ruoyi.frequency.platformanswer.entity.PlatformAnswer;
import com.baomidou.mybatisplus.extension.service.IService;

/**
 * 平台有问必答Service接口
 * 
 * @author liwenlong
 * @date 2024-01-24
 */
public interface PlatformAnswerService extends IService<PlatformAnswer>
{
    /**
     * 查询平台有问必答
     * 
     * @param id 平台有问必答主键
     * @return 平台有问必答
     */
    public PlatformAnswer selectPlatformAnswerById(Long id);

    /**
     * 查询平台有问必答列表
     * 
     * @param platformAnswer 平台有问必答
     * @return 平台有问必答集合
     */
    public List<PlatformAnswer> selectPlatformAnswerList(PlatformAnswer platformAnswer);

    /**
     * 新增平台有问必答
     * 
     * @param platformAnswer 平台有问必答
     * @return 结果
     */
    public int insertPlatformAnswer(PlatformAnswer platformAnswer);

    /**
     * 修改平台有问必答
     * 
     * @param platformAnswer 平台有问必答
     * @return 结果
     */
    public int updatePlatformAnswer(PlatformAnswer platformAnswer);

    /**
     * 批量删除平台有问必答
     * 
     * @param ids 需要删除的平台有问必答主键集合
     * @return 结果
     */
    public int deletePlatformAnswerByIds(Long[] ids,Integer delFlag);

}
